
( function ( blocks, element, blockEditor ) {
    const el = element.createElement,
        registerBlockType = blocks.registerBlockType,
        ServerSideRender = PgServerSideRender,
        InspectorControls = blockEditor.InspectorControls,
        useBlockProps = blockEditor.useBlockProps;
        
    const {__} = wp.i18n;
    const {ColorPicker, TextControl, ToggleControl, SelectControl, Panel, PanelBody, Disabled, TextareaControl, BaseControl} = wp.components;
    const {useSelect} = wp.data;
    const {RawHTML, Fragment} = element;
   
    const {InnerBlocks, URLInputButton, RichText} = wp.blockEditor;
    const useInnerBlocksProps = blockEditor.useInnerBlocksProps || blockEditor.__experimentalUseInnerBlocksProps;
    
    const propOrDefault = function(val, prop, field) {
        if(block.attributes[prop] && (val === null || val === '')) {
            return field ? block.attributes[prop].default[field] : block.attributes[prop].default;
        }
        return val;
    }
    
    const block = registerBlockType( 'flexwebsite/footer', {
        apiVersion: 2,
        title: 'Footer',
        icon: 'block-default',
        category: 'flex',
        keywords: [],
        supports: {color: {background: false,text: false,gradients: false,link: false,},typography: {fontSize: false,},anchor: false,align: false,},
        attributes: {
            logo: {
                type: 'object',
                default: {id: 0, url: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/flex-ui-green.svg', size: ''},
            },
            tagline: {
                type: 'text',
                default: `Launch your own Software As A Service Application with Flex Solutions.`,
            },
            menu_1_title: {
                type: 'text',
                default: `Product`,
            },
            menu_2_title: {
                type: 'text',
                default: `Remaining`,
            },
            form_title: {
                type: 'text',
                default: `Newsletter`,
            }
        },
        example: { attributes: { logo: {id: 0, url: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/flex-ui-green.svg', size: ''}, tagline: `Launch your own Software As A Service Application with Flex Solutions.`, menu_1_title: `Product`, menu_2_title: `Remaining`, form_title: `Newsletter` } },
        edit: function ( props ) {
            const blockProps = useBlockProps({ className: 'bg-white' });
            const setAttributes = props.setAttributes; 
            
            props.logo = useSelect(function( select ) {
                return {
                    logo: props.attributes.logo.id ? select('core').getMedia(props.attributes.logo.id) : undefined
                };
            }, [props.attributes.logo] ).logo;
            
            const innerBlocksProps = null;
            
            
            return el(Fragment, {}, [
                
                        el( ServerSideRender, {
                            block: 'flexwebsite/footer',
                            httpMethod: 'POST',
                            attributes: props.attributes,
                            innerBlocksProps: innerBlocksProps,
                            blockProps: blockProps
                        } ),                        
                
                    el( InspectorControls, {},
                        [
                            
                        pgMediaImageControl('logo', setAttributes, props, 'full', true, 'Logo', '' ),
                                        
                            el(Panel, {},
                                el(PanelBody, {
                                    title: __('Block properties')
                                }, [
                                    
                                    el(TextControl, {
                                        value: props.attributes.tagline,
                                        help: __( '' ),
                                        label: __( 'Tagline' ),
                                        onChange: function(val) { setAttributes({tagline: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.menu_1_title,
                                        help: __( '' ),
                                        label: __( 'Menu 1 title' ),
                                        onChange: function(val) { setAttributes({menu_1_title: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.menu_2_title,
                                        help: __( '' ),
                                        label: __( 'Menu 2 title' ),
                                        onChange: function(val) { setAttributes({menu_2_title: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.form_title,
                                        help: __( '' ),
                                        label: __( 'Form title' ),
                                        onChange: function(val) { setAttributes({form_title: val}) },
                                        type: 'text'
                                    }),    
                                ])
                            )
                        ]
                    )                            

            ]);
        },

        save: function(props) {
            return null;
        }                        

    } );
} )(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
);                        
