
( function ( blocks, element, blockEditor ) {
    const el = element.createElement,
        registerBlockType = blocks.registerBlockType,
        ServerSideRender = PgServerSideRender,
        InspectorControls = blockEditor.InspectorControls,
        useBlockProps = blockEditor.useBlockProps;
        
    const {__} = wp.i18n;
    const {ColorPicker, TextControl, ToggleControl, SelectControl, Panel, PanelBody, Disabled, TextareaControl, BaseControl} = wp.components;
    const {useSelect} = wp.data;
    const {RawHTML, Fragment} = element;
   
    const {InnerBlocks, URLInputButton, RichText} = wp.blockEditor;
    const useInnerBlocksProps = blockEditor.useInnerBlocksProps || blockEditor.__experimentalUseInnerBlocksProps;
    
    const propOrDefault = function(val, prop, field) {
        if(block.attributes[prop] && (val === null || val === '')) {
            return field ? block.attributes[prop].default[field] : block.attributes[prop].default;
        }
        return val;
    }
    
    const block = registerBlockType( 'flexwebsite/hero', {
        apiVersion: 2,
        title: 'Hero',
        icon: 'block-default',
        category: 'flex',
        keywords: [],
        supports: {color: {background: false,text: false,gradients: false,link: false,},typography: {fontSize: false,},anchor: false,align: false,},
        attributes: {
            label: {
                type: 'text',
                default: `Header`,
            },
            title: {
                type: 'text',
                default: `A small business is only as good as its tools.`,
            },
            description: {
                type: 'text',
                default: `We’re different. Flex is the only saas business platform that lets you run your business on one platform, seamlessly across all digital channels.`,
            },
            request_link: {
                type: 'object',
                default: {post_id: 0, url: '#', title: '', 'post_type': null},
            },
            request_label: {
                type: 'text',
                default: `Request a Demo`,
            },
            signup_link: {
                type: 'object',
                default: {post_id: 0, url: '', title: '', 'post_type': null},
            },
            signup_label: {
                type: 'text',
                default: `Sign Up`,
            },
            image: {
                type: 'object',
                default: {id: 0, url: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/header.jpg', size: ''},
            }
        },
        example: { attributes: { label: `Header`, title: `A small business is only as good as its tools.`, description: `We’re different. Flex is the only saas business platform that lets you run your business on one platform, seamlessly across all digital channels.`, request_link: {post_id: 0, url: '#', title: '', 'post_type': null}, request_label: `Request a Demo`, signup_link: {post_id: 0, url: '#', title: '', 'post_type': null}, signup_label: `Sign Up`, image: {id: 0, url: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/header.jpg', size: ''} } },
        edit: function ( props ) {
            const blockProps = useBlockProps({ className: 'relative bg-white overflow-hidden', style: { backgroundPosition: 'center',backgroundImage: 'url(\'' + (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/pattern-white.svg\')' } });
            const setAttributes = props.setAttributes; 
            
            props.image = useSelect(function( select ) {
                return {
                    image: props.attributes.image.id ? select('core').getMedia(props.attributes.image.id) : undefined
                };
            }, [props.attributes.image] ).image;
            
            const innerBlocksProps = null;
            
            
            return el(Fragment, {}, [
                el('section', { ...blockProps }, el('div', { className: 'py-20 md:py-28' }, el('div', { className: 'container px-4 mx-auto' }, el('div', { className: 'flex flex-wrap xl:items-center -mx-4' }, [el('div', { className: 'w-full md:w-1/2 px-4 mb-16 md:mb-0' }, [el(RichText, { tagName: 'span', className: 'bg-green-500 inline-block leading-5 mb-4 px-2 py-px rounded-full text-white text-xs uppercase', value: propOrDefault( props.attributes.label, 'label' ), onChange: function(val) { setAttributes( {label: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el(RichText, { tagName: 'h1', className: 'font-bold leading-tight mb-6 text-3xl tracking-tight md:leading-tight md:text-5xl lg:leading-tight lg:text-6xl', value: propOrDefault( props.attributes.title, 'title' ), onChange: function(val) { setAttributes( {title: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el(RichText, { tagName: 'p', className: 'mb-8 text-lg md:text-xl text-coolGray-500 font-medium', value: propOrDefault( props.attributes.description, 'description' ), onChange: function(val) { setAttributes( {description: val }) } }), el('div', { className: 'flex flex-wrap' }, [el('div', { className: 'w-full md:w-auto py-1 md:py-0 md:mr-4' }, el(RichText, { tagName: 'a', className: 'inline-block py-5 px-7 w-full text-base md:text-lg leading-4 text-green-50 font-medium text-center bg-green-500 hover:bg-green-600 focus:ring-2 focus:ring-green-500 focus:ring-opacity-50 border border-green-500 rounded-md shadow-sm', href: '#', value: propOrDefault( props.attributes.request_label, 'request_label' ), onChange: function(val) { setAttributes( {request_label: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] })), el('div', { className: 'w-full md:w-auto py-1 md:py-0' }, props.attributes.signup_link && props.attributes.signup_link.url && el(RichText, { tagName: 'a', className: 'inline-block py-5 px-7 w-full text-base md:text-lg leading-4 text-coolGray-800 font-medium text-center bg-white hover:bg-coolGray-100 focus:ring-2 focus:ring-coolGray-200 focus:ring-opacity-50 border border-coolGray-200 rounded-md shadow-sm', href: '#', value: propOrDefault( props.attributes.signup_label, 'signup_label' ), onChange: function(val) { setAttributes( {signup_label: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }))])]), el('div', { className: 'w-full md:w-1/2 px-4' }, el('div', { className: 'relative mx-auto md:mr-0 max-w-max' }, [el('img', { className: 'absolute z-10 -left-14 -top-12 w-28 md:w-auto', src: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/circle3-yellow.svg', alt: '' }), el('img', { className: 'absolute z-10 -right-7 -bottom-8 w-28 md:w-auto', src: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/dots3-blue.svg', alt: '' }), props.attributes.image && props.attributes.image.svg && pgCreateSVG(RawHTML, {}, pgMergeInlineSVGAttributes(propOrDefault( props.attributes.image.svg, 'image', 'svg' ), { className: 'relative rounded-3xl' })), props.attributes.image && !props.attributes.image.svg && propOrDefault( props.attributes.image.url, 'image', 'url' ) && el('img', { className: 'relative rounded-3xl', src: propOrDefault( props.attributes.image.url, 'image', 'url' ), alt: '' })]))])))),                        
                
                    el( InspectorControls, {},
                        [
                            
                        pgMediaImageControl('image', setAttributes, props, 'medium', true, 'Image', '' ),
                                        
                            el(Panel, {},
                                el(PanelBody, {
                                    title: __('Block properties')
                                }, [
                                    
                                    el(TextControl, {
                                        value: props.attributes.label,
                                        help: __( '' ),
                                        label: __( 'Section label' ),
                                        onChange: function(val) { setAttributes({label: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.title,
                                        help: __( '' ),
                                        label: __( 'Title' ),
                                        onChange: function(val) { setAttributes({title: val}) },
                                        type: 'text'
                                    }),
                                    el(BaseControl, {
                                        help: __( '' ),
                                        label: __( 'Description' ),
                                    }, [
                                        el(RichText, {
                                            value: props.attributes.description,
                                            style: {
                                                    border: '1px solid black',
                                                    padding: '6px 8px',
                                                    minHeight: '80px',
                                                    border: '1px solid rgb(117, 117, 117)',
                                                    fontSize: '13px',
                                                    lineHeight: 'normal'
                                                },
                                            onChange: function(val) { setAttributes({description: val}) },
                                        })
                                    ]),
                                    pgUrlControl('request_link', setAttributes, props, 'Request link', '', null ),
                                    el(TextControl, {
                                        value: props.attributes.request_label,
                                        help: __( '' ),
                                        label: __( 'Request label' ),
                                        onChange: function(val) { setAttributes({request_label: val}) },
                                        type: 'text'
                                    }),
                                    pgUrlControl('signup_link', setAttributes, props, 'Signup link', '', null ),
                                    el(TextControl, {
                                        value: props.attributes.signup_label,
                                        help: __( '' ),
                                        label: __( 'Signup label' ),
                                        onChange: function(val) { setAttributes({signup_label: val}) },
                                        type: 'text'
                                    }),    
                                ])
                            )
                        ]
                    )                            

            ]);
        },

        save: function(props) {
            const blockProps = useBlockProps.save({ className: 'relative bg-white overflow-hidden', style: { backgroundPosition: 'center',backgroundImage: 'url(\'' + (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/pattern-white.svg\')' } });
            return el('section', { ...blockProps }, el('div', { className: 'py-20 md:py-28' }, el('div', { className: 'container px-4 mx-auto' }, el('div', { className: 'flex flex-wrap xl:items-center -mx-4' }, [el('div', { className: 'w-full md:w-1/2 px-4 mb-16 md:mb-0' }, [el(RichText.Content, { tagName: 'span', className: 'bg-green-500 inline-block leading-5 mb-4 px-2 py-px rounded-full text-white text-xs uppercase', value: propOrDefault( props.attributes.label, 'label' ) }), el(RichText.Content, { tagName: 'h1', className: 'font-bold leading-tight mb-6 text-3xl tracking-tight md:leading-tight md:text-5xl lg:leading-tight lg:text-6xl', value: propOrDefault( props.attributes.title, 'title' ) }), el(RichText.Content, { tagName: 'p', className: 'mb-8 text-lg md:text-xl text-coolGray-500 font-medium', value: propOrDefault( props.attributes.description, 'description' ) }), el('div', { className: 'flex flex-wrap' }, [el('div', { className: 'w-full md:w-auto py-1 md:py-0 md:mr-4' }, el(RichText.Content, { tagName: 'a', className: 'inline-block py-5 px-7 w-full text-base md:text-lg leading-4 text-green-50 font-medium text-center bg-green-500 hover:bg-green-600 focus:ring-2 focus:ring-green-500 focus:ring-opacity-50 border border-green-500 rounded-md shadow-sm', href: propOrDefault( props.attributes.request_link.url, 'request_link', 'url' ), value: propOrDefault( props.attributes.request_label, 'request_label' ) })), el('div', { className: 'w-full md:w-auto py-1 md:py-0' }, props.attributes.signup_link && props.attributes.signup_link.url && el(RichText.Content, { tagName: 'a', className: 'inline-block py-5 px-7 w-full text-base md:text-lg leading-4 text-coolGray-800 font-medium text-center bg-white hover:bg-coolGray-100 focus:ring-2 focus:ring-coolGray-200 focus:ring-opacity-50 border border-coolGray-200 rounded-md shadow-sm', href: props.attributes.signup_link.url, value: propOrDefault( props.attributes.signup_label, 'signup_label' ) }))])]), el('div', { className: 'w-full md:w-1/2 px-4' }, el('div', { className: 'relative mx-auto md:mr-0 max-w-max' }, [el('img', { className: 'absolute z-10 -left-14 -top-12 w-28 md:w-auto', src: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/circle3-yellow.svg', alt: '' }), el('img', { className: 'absolute z-10 -right-7 -bottom-8 w-28 md:w-auto', src: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/dots3-blue.svg', alt: '' }), props.attributes.image && props.attributes.image.svg && pgCreateSVG(RawHTML, {}, pgMergeInlineSVGAttributes(propOrDefault( props.attributes.image.svg, 'image', 'svg' ), { className: 'relative rounded-3xl' })), props.attributes.image && !props.attributes.image.svg && propOrDefault( props.attributes.image.url, 'image', 'url' ) && el('img', { className: 'relative rounded-3xl', src: propOrDefault( props.attributes.image.url, 'image', 'url' ), alt: '' })]))]))));
        }                        

    } );
} )(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
);                        
