
( function ( blocks, element, blockEditor ) {
    const el = element.createElement,
        registerBlockType = blocks.registerBlockType,
        ServerSideRender = PgServerSideRender,
        InspectorControls = blockEditor.InspectorControls,
        useBlockProps = blockEditor.useBlockProps;
        
    const {__} = wp.i18n;
    const {ColorPicker, TextControl, ToggleControl, SelectControl, Panel, PanelBody, Disabled, TextareaControl, BaseControl} = wp.components;
    const {useSelect} = wp.data;
    const {RawHTML, Fragment} = element;
   
    const {InnerBlocks, URLInputButton, RichText} = wp.blockEditor;
    const useInnerBlocksProps = blockEditor.useInnerBlocksProps || blockEditor.__experimentalUseInnerBlocksProps;
    
    const propOrDefault = function(val, prop, field) {
        if(block.attributes[prop] && (val === null || val === '')) {
            return field ? block.attributes[prop].default[field] : block.attributes[prop].default;
        }
        return val;
    }
    
    const block = registerBlockType( 'flexwebsite/testimonial', {
        apiVersion: 2,
        title: 'Testimonial',
        icon: 'block-default',
        category: 'flex',
        parent: [ 'flexwebsite/slide' ],

        keywords: [],
        supports: {color: {background: false,text: false,gradients: false,link: false,},typography: {fontSize: false,},anchor: false,align: false,},
        attributes: {
            quote: {
                type: 'text',
                default: `The best solution for anyone who wants to work a flexible schedule but still earn a full-time income.`,
            },
            image: {
                type: 'object',
                default: {id: 0, url: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/avatar1.png', size: ''},
            },
            name: {
                type: 'text',
                default: `Darren Dunlap`,
            },
            position: {
                type: 'text',
                default: `CEO &amp; Founder at Flex.co`,
            }
        },
        example: { attributes: { quote: `The best solution for anyone who wants to work a flexible schedule but still earn a full-time income.`, image: {id: 0, url: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/avatar1.png', size: ''}, name: `Darren Dunlap`, position: `CEO &amp; Founder at Flex.co` } },
        edit: function ( props ) {
            const blockProps = useBlockProps({});
            const setAttributes = props.setAttributes; 
            
            props.image = useSelect(function( select ) {
                return {
                    image: props.attributes.image.id ? select('core').getMedia(props.attributes.image.id) : undefined
                };
            }, [props.attributes.image] ).image;
            
            const innerBlocksProps = null;
            
            
            return el(Fragment, {}, [
                el('div', { ...blockProps }, [el('div', { className: 'max-w-5xl mb-10 min-h-[90px] mx-auto pb-6 relative text-center sm:px-6' }, [el('img', { className: 'absolute top-0 left-0', src: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/quote-top-green.svg', alt: '' }), el('img', { className: 'absolute bottom-0 right-0', src: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/quote-down-green.svg', alt: '' }), el('div', { className: 'relative' }, el(RichText, { tagName: 'h2', className: 'text-2xl md:text-5xl font-semibold tracking-tighter', value: propOrDefault( props.attributes.quote, 'quote' ), onChange: function(val) { setAttributes( {quote: val }) } }))]), el('div', { className: 'text-center mb-8' }, [props.attributes.image && props.attributes.image.svg && pgCreateSVG(RawHTML, {}, pgMergeInlineSVGAttributes(propOrDefault( props.attributes.image.svg, 'image', 'svg' ), { className: 'w-24 h-24 mx-auto mb-6 rounded-full' })), props.attributes.image && !props.attributes.image.svg && propOrDefault( props.attributes.image.url, 'image', 'url' ) && el('img', { className: 'w-24 h-24 mx-auto mb-6 rounded-full', src: propOrDefault( props.attributes.image.url, 'image', 'url' ), alt: '' }), el(RichText, { tagName: 'h3', className: 'mb-2 text-xl md:text-2xl font-semibold', value: propOrDefault( props.attributes.name, 'name' ), onChange: function(val) { setAttributes( {name: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el(RichText, { tagName: 'span', className: 'text-lg text-coolGray-500 font-medium', value: propOrDefault( props.attributes.position, 'position' ), onChange: function(val) { setAttributes( {position: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] })])]),                        
                
                    el( InspectorControls, {},
                        [
                            
                        pgMediaImageControl('image', setAttributes, props, 'thumbnail', true, 'Image', '' ),
                                        
                            el(Panel, {},
                                el(PanelBody, {
                                    title: __('Block properties')
                                }, [
                                    
                                    el(BaseControl, {
                                        help: __( '' ),
                                        label: __( 'Quote' ),
                                    }, [
                                        el(RichText, {
                                            value: props.attributes.quote,
                                            style: {
                                                    border: '1px solid black',
                                                    padding: '6px 8px',
                                                    minHeight: '80px',
                                                    border: '1px solid rgb(117, 117, 117)',
                                                    fontSize: '13px',
                                                    lineHeight: 'normal'
                                                },
                                            onChange: function(val) { setAttributes({quote: val}) },
                                        })
                                    ]),
                                    el(TextControl, {
                                        value: props.attributes.name,
                                        help: __( '' ),
                                        label: __( 'Name' ),
                                        onChange: function(val) { setAttributes({name: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.position,
                                        help: __( '' ),
                                        label: __( 'Position' ),
                                        onChange: function(val) { setAttributes({position: val}) },
                                        type: 'text'
                                    }),    
                                ])
                            )
                        ]
                    )                            

            ]);
        },

        save: function(props) {
            const blockProps = useBlockProps.save({});
            return el('div', { ...blockProps }, [el('div', { className: 'max-w-5xl mb-10 min-h-[90px] mx-auto pb-6 relative text-center sm:px-6' }, [el('img', { className: 'absolute top-0 left-0', src: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/quote-top-green.svg', alt: '' }), el('img', { className: 'absolute bottom-0 right-0', src: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/quote-down-green.svg', alt: '' }), el('div', { className: 'relative' }, el(RichText.Content, { tagName: 'h2', className: 'text-2xl md:text-5xl font-semibold tracking-tighter', value: propOrDefault( props.attributes.quote, 'quote' ) }))]), el('div', { className: 'text-center mb-8' }, [props.attributes.image && props.attributes.image.svg && pgCreateSVG(RawHTML, {}, pgMergeInlineSVGAttributes(propOrDefault( props.attributes.image.svg, 'image', 'svg' ), { className: 'w-24 h-24 mx-auto mb-6 rounded-full' })), props.attributes.image && !props.attributes.image.svg && propOrDefault( props.attributes.image.url, 'image', 'url' ) && el('img', { className: 'w-24 h-24 mx-auto mb-6 rounded-full', src: propOrDefault( props.attributes.image.url, 'image', 'url' ), alt: '' }), el(RichText.Content, { tagName: 'h3', className: 'mb-2 text-xl md:text-2xl font-semibold', value: propOrDefault( props.attributes.name, 'name' ) }), el(RichText.Content, { tagName: 'span', className: 'text-lg text-coolGray-500 font-medium', value: propOrDefault( props.attributes.position, 'position' ) })])]);
        }                        

    } );
} )(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
);                        
